@@ -611,6 +611,8 @@ app_indicator_init (AppIndicator *self)
 	priv->sec_activate_target = NULL;
 	priv->sec_activate_enabled = FALSE;
 
+	self->priv = priv;
+
 	/* Start getting the session bus */
 	g_object_ref(self); /* ref for the bus creation callback */
 	g_bus_get(G_BUS_TYPE_SESSION, NULL, bus_creation, self);
@@ -618,8 +620,6 @@ app_indicator_init (AppIndicator *self)
 	g_signal_connect(G_OBJECT(gtk_icon_theme_get_default()),
 		"changed", G_CALLBACK(theme_changed_cb), self);
 
-	self->priv = priv;
-
 	return;
 }
 
@@ -1123,7 +1123,18 @@ bus_get_prop (GDBusConnection * connection, const gchar * sender, const gchar *
 	} else if (g_strcmp0(property, "AttentionIconName") == 0) {
 		return g_variant_new_string(priv->attention_icon_name ? priv->attention_icon_name : "");
 	} else if (g_strcmp0(property, "Title") == 0) {
-		return g_variant_new_string(priv->title ? priv->title : "");
+		const gchar * output = NULL;
+		if (priv->title == NULL) {
+			const gchar * name = g_get_application_name();
+			if (name != NULL) {
+				output = name;
+			} else {
+				output = "";
+			}
+		} else {
+			output = priv->title;
+		}
+		return g_variant_new_string(output);
 	} else if (g_strcmp0(property, "IconThemePath") == 0) {
 		return g_variant_new_string(priv->icon_theme_path ? priv->icon_theme_path : "");
 	} else if (g_strcmp0(property, "Menu") == 0) {
@@ -1875,20 +1886,14 @@ app_indicator_set_attention_icon_full (AppIndicator *self, const gchar *icon_nam
 	gboolean changed = FALSE;
 
 	if (g_strcmp0 (self->priv->attention_icon_name, icon_name) != 0) {
-		if (self->priv->attention_icon_name) {
-			g_free (self->priv->attention_icon_name);
-		}
-
-		self->priv->attention_icon_name = g_strdup(icon_name);
+		g_free (self->priv->attention_icon_name);
+		self->priv->attention_icon_name = g_strdup (icon_name);
 		changed = TRUE;
 	}
 
 	if (g_strcmp0(self->priv->att_accessible_desc, icon_desc) != 0) {
-		if (self->priv->att_accessible_desc) {
-			g_free (self->priv->att_accessible_desc);
-		}
-
-		self->priv->att_accessible_desc = g_strdup(icon_name);
+		g_free (self->priv->att_accessible_desc);
+		self->priv->att_accessible_desc = g_strdup (icon_desc);
 		changed = TRUE;
 	}
 
@@ -1899,12 +1904,12 @@ app_indicator_set_attention_icon_full (AppIndicator *self, const gchar *icon_nam
 			GError * error = NULL;
 
 			g_dbus_connection_emit_signal(self->priv->connection,
-										  NULL,
-										  self->priv->path,
-										  NOTIFICATION_ITEM_DBUS_IFACE,
-										  "NewAttentionIcon",
-										  NULL,
-										  &error);
+			                              NULL,
+			                              self->priv->path,
+			                              NOTIFICATION_ITEM_DBUS_IFACE,
+			                              "NewAttentionIcon",
+			                              NULL,
+			                              &error);
 
 			if (error != NULL) {
 				g_warning("Unable to send signal for NewAttentionIcon: %s", error->message);
@@ -2474,7 +2479,7 @@ shorty_activated_cb (DbusmenuMenuitem * mi, guint timestamp, gpointer user_data)
 
 	g_return_if_fail(priv->shorties != NULL);
 
-	indicator_desktop_shortcuts_nick_exec(priv->shorties, nick);
+	indicator_desktop_shortcuts_nick_exec_with_context(priv->shorties, nick, NULL);
 
 	return;
 }
